#[non_exhaustive]pub enum Backend {
Cache,
Mmap,
}Expand description
Backend used by the Btf object to store and access the underlying BTF
information.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cache
Parse the BTF data during initialization and then store the result. This provides faster API calls at the cost of a slower initialization and larger memory footprint.
Mmap
Mmap the BTF data without parsing all of it. This provides a smaller memory footprint and faster initialization at the cost of slower API calls.